## BaiduNetdisk OpenAPI Client

An API library for [BaiduNetdisk](https://pan.baidu.com/union/doc/Kl4gsu388)

Generated by: [https://openapi-generator.tech](https://openapi-generator.tech)



### Library Struct

```
xpan
│  api_client.py
│  configuration.py
│  exceptions.py
│  model_utils.py
│  rest.py
│  __init__.py
│
├─api
│      auth_api.py
│      fileinfo_api.py
│      filemanager_api.py
│      fileupload_api.py
│      multimediafile_api.py
│      userinfo_api.py
│      __init__.py
│
└─model
        oauth_token_authorization_code_response.py
        oauth_token_device_code_response.py
        oauth_token_device_token_response.py
        oauth_token_refresh_token_response.py
        quotaresponse.py
        uinforesponse.py
        __init__.py
```



### Example

```python
import os,sys
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.append(BASE_DIR)
import xpan
from xpan.api import userinfo_api
from xpan.model.quotaresponse import Quotaresponse
from xpan.model.uinforesponse import Uinforesponse
from pprint import pprint

def user_quota():
    """
    user_quota demo
    """
    # Enter a context with an instance of the API client
    with xpan.ApiClient() as api_client:
        # Create an instance of the API class
        api_instance = userinfo_api.UserinfoApi(api_client)
        access_token = "123.56c5d1f8eedf1f9404c547282c5dbcf4.YmmjpAlsjUFbPly3mJizVYqdfGDLsBaY5pyg3qL.a9IIIQ" # str | 
        checkexpire = 1 # int |  (optional)
        checkfree = 1 # int |  (optional)

        # example passing only required values which don't have defaults set
        # and optional values
        try:
            api_response = api_instance.apiquota(access_token, checkexpire=checkexpire, checkfree=checkfree)
            pprint(api_response)
        except xpan.ApiException as e:
            print("Exception when calling UserinfoApi->apiquota: %s\n" % e) 


def user_info():
    """
    user_info demo
    """
    # Enter a context with an instance of the API client
    with xpan.ApiClient() as api_client:
        # Create an instance of the API class
        api_instance = userinfo_api.UserinfoApi(api_client)
        access_token = "123.56c5d1f8eedf1f9404c547282c5dbcf4.YmmjpAlsjUFbPly3mJizVYqdfGDLsBaY5pyg3qL.a9IIIQ" # str | 

        # example passing only required values which don't have defaults set
        try:
            api_response = api_instance.xpannasuinfo(access_token)
            pprint(api_response)
        except xpan.ApiException as e:
            print("Exception when calling UserinfoApi->xpannasuinfo: %s\n" % e)


```